<div align="center">
    <br><img src="https://github.com/ThiagoPanini/pynvest/blob/v0.0.x/docs/assets/gifs/logo-animated-intro.gif?raw=true" alt="pynvest-animated-intro">
</div>

> **Note**
> Tão logo quanto possível, esta biblioteca estará totalmente documentada e pronta para uso.

___

## Entre em contato comigo

- GitHub: [@ThiagoPanini](https://github.com/ThiagoPanini)
- LinkedIn: [Thiago Panini](https://www.linkedin.com/in/thiago-panini/)
- Hashnode: [panini-tech-lab](https://panini.hashnode.dev/)
- DevTo: [thiagopanini](https://dev.to/thiagopanini)